@@ -212,7 +212,7 @@ def get_session_name(vtiger_access):
         print("unable to get required data from vtiger_access")
 
 
-def trigger_workflow(workflow, event_type, data, service_url, api_access_key):
+def trigger_workflow(workflow, event_type, data, service_url, api_access_key, source_module):
     """ call API to trigger any workflow
         Required params: 1. workflow 2. event_type 3. data"""
 
@@ -224,11 +224,13 @@ def trigger_workflow(workflow, event_type, data, service_url, api_access_key):
     print(f"Event Type: {event_type}")
     print(f"Data Type: {data}")
     print(f"Service URl: {service_url}")
+    print(f"source_module: {source_module}")
     if data:
         payload = {
             "workflow": workflow,
             "data": data,
-            "eventtype": event_type
+            "eventtype": event_type,
+            "source_module": source_module
         }
 
         response, status = invoke_http_request(endpoint, 'POST', headers, json_data=payload, timeout=61)
@@ -276,6 +278,7 @@ def run_external_workflow(conf, task_id, vtiger_access):
         if external_workflow_config:
 
             data = conf.get('data', '')
+            source_module = conf.get('source_module', '')
             workflow = external_workflow_config.get('workflow', '')
             event_type = external_workflow_config.get('event_type', '')
 
@@ -357,25 +360,28 @@ def run_external_workflow(conf, task_id, vtiger_access):
 
                 if response:
                     # trigger only if condition is satisfied
-                    if response.get('result') and workflow and event_type:
+                    if response.get('result') and workflow and event_type and module:
 
                         if event_type == 'import' or event_type == 'manual':
                             # if event type = import/ manual then pass list
 
                             trigger_workflow(workflow, event_type, response.get('result'),
-                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
+                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'), module)
                         else:
                             trigger_workflow(workflow, event_type, response.get('result')[0],
-                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'))
-            elif workflow and event_type and data:
+                                             vtiger_access.get('service_url'), vtiger_access.get('api_access_key'), module)
+            elif workflow and event_type and data and source_module:
                 # trigger without condition
                 if event_type == 'import' or event_type == 'manual':
                     list_of_data = [data]
                     trigger_workflow(workflow, event_type, list_of_data, vtiger_access.get('service_url'),
-                                     vtiger_access.get('api_access_key'))
+                                     vtiger_access.get('api_access_key'), source_module)
                 else:
                     trigger_workflow(workflow, event_type, data, vtiger_access.get('service_url'),
-                                     vtiger_access.get('api_access_key'))
+                                     vtiger_access.get('api_access_key'), source_module)
+
+            else:
+                print("Unable to get required data: workflow, event_type, data and source_module from payload ")
         else:
             print("external_workflow_config not found for task id:", task_id)
     else:
